@@ -26,7 +26,7 @@
 #' @importFrom jsonlite read_json
 #' @importFrom dplyr tibble
 #' @export
-readCohortSet <- function(path) {
+read_cohort_set <- function(path) {
   checkmate::checkCharacter(path, len = 1, min.chars = 1)
 
   if (!fs::is_dir(path)) {
@@ -58,6 +58,10 @@ readCohortSet <- function(path) {
 }
 
 
+#' @export
+#' @rdname read_cohort_set
+readCohortSet <- read_cohort_set
+
 
 #' Generate a cohort set on a cdm object
 #'
@@ -93,8 +97,8 @@ readCohortSet <- function(path) {
 #'   specified.
 #' @param name Name of the cohort table to be created. This will also be used
 #' as a prefix for the cohort attribute tables.
-#' @param cohortSet A cohortSet object created with `readCohortSet()`.
-#' @param computeAttrition Should attrition be computed? TRUE or FALSE (default)
+#' @param cohort_set,cohortSet A cohortSet object created with `readCohortSet()`.
+#' @param compute_attrition,computeAttrition Should attrition be computed? TRUE or FALSE (default)
 #' @param overwrite Should the cohort table be overwritten if it already
 #' exists? TRUE or FALSE (default)
 #' @export
@@ -201,7 +205,6 @@ generateCohortSet <- function(cdm,
                          name = "VARCHAR(255)",
                          description = "VARCHAR(1000)")
     )
-    # on.exit(DBI::dbRemoveTable(con, inSchema(writeSchema, nm)), add = TRUE)
 
     nm <- paste0(name, "_inclusion_result") # used for attrition
 
@@ -217,7 +220,6 @@ generateCohortSet <- function(cdm,
                          person_count = "INT",
                          mode_id = "INT")
     )
-    # on.exit(DBI::dbRemoveTable(con, inSchema(writeSchema, nm)), add = TRUE)
 
     nm <- paste0(name, "_inclusion_stats")
 
@@ -235,7 +237,6 @@ generateCohortSet <- function(cdm,
                          person_total = "INT",
                          mode_id = "INT")
     )
-    # on.exit(DBI::dbRemoveTable(con, inSchema(writeSchema, nm)), add = TRUE)
 
 
     nm <- paste0(name, "_summary_stats")
@@ -252,7 +253,6 @@ generateCohortSet <- function(cdm,
                          final_count = "INT",
                          mode_id = "INT")
     )
-    # on.exit(DBI::dbRemoveTable(con, inSchema(writeSchema, nm)), add = TRUE)
 
     nm <- paste0(name, "_censor_stats")
 
@@ -266,7 +266,6 @@ generateCohortSet <- function(cdm,
                          cohort_definition_id = "INT",
                          lost_count = "INT")
     )
-    # on.exit(DBI::dbRemoveTable(con, inSchema(writeSchema, nm)), add = TRUE)
   }
 
   # Run the OHDSI-SQL ----
@@ -301,9 +300,7 @@ generateCohortSet <- function(cdm,
     sql <- SqlRender::translate(sql, targetDialect = CDMConnector::dbms(con)) %>%
       SqlRender::splitSql()
 
-    DBI::dbWithTransaction(con,
-      purrr::walk(sql, ~DBI::dbExecute(con, .x, immediate = TRUE))
-    )
+    purrr::walk(sql, ~DBI::dbExecute(con, .x, immediate = TRUE))
     cli::cli_progress_update()
   }
   cli::cli_progress_done()
@@ -314,7 +311,8 @@ generateCohortSet <- function(cdm,
   if (computeAttrition) {
     cohort_attrition_ref <- computeAttritionTable(cdm,
                                                   cohortStem = name,
-                                                  cohortSet = cohortSet)
+                                                  cohortSet = cohortSet,
+                                                  overwrite = overwrite)
   } else {
     cohort_attrition_ref <- NULL
   }
@@ -331,21 +329,21 @@ generateCohortSet <- function(cdm,
   cohort_count_ref <- cohort_ref %>%
     dplyr::ungroup() %>%
     dplyr::group_by(.data$cohort_definition_id) %>%
-    dplyr::summarise(cohort_entries = dplyr::n(),
-                     cohort_subjects = dplyr::n_distinct(.data$subject_id)) %>%
+    dplyr::summarise(number_records = dplyr::n(),
+                     number_subjects = dplyr::n_distinct(.data$subject_id)) %>%
     {dplyr::left_join(cohort_set_ref, ., by = "cohort_definition_id")} %>%
-    dplyr::mutate(cohort_entries  = dplyr::coalesce(.data$cohort_entries, 0L),
-                  cohort_subjects = dplyr::coalesce(.data$cohort_entries, 0L)) %>%
+    dplyr::mutate(number_records  = dplyr::coalesce(.data$number_records, 0L),
+                  number_subjects = dplyr::coalesce(.data$number_subjects, 0L)) %>%
     dplyr::select("cohort_definition_id",
-                  "cohort_entries",
-                  "cohort_subjects") %>%
+                  "number_records",
+                  "number_subjects") %>%
     computeQuery(name = paste0(name, "_count"),
                  schema = attr(cdm, "write_schema"),
                  temporary = FALSE,
                  overwrite = TRUE)
 
-  # Clean up tables ----
-  if (computeAttrition) {
+  # Clean up tables ---- TODO decide how to handle this
+  if (FALSE) {
     DBI::dbRemoveTable(con, inSchema(writeSchema, paste0(name, "_inclusion")))
     DBI::dbRemoveTable(con, inSchema(writeSchema, paste0(name, "_inclusion_result")))
     DBI::dbRemoveTable(con, inSchema(writeSchema, paste0(name, "_inclusion_stats")))
@@ -354,7 +352,7 @@ generateCohortSet <- function(cdm,
   }
 
   # Create the object. Let the constructor handle getting the counts.----
-  cdm[[name]] <- newGeneratedCohortSet(
+  cdm[[name]] <- new_generated_cohort_set(
     cohort_ref = cohort_ref,
     cohort_set_ref = cohort_set_ref,
     cohort_attrition_ref = cohort_attrition_ref,
@@ -363,6 +361,23 @@ generateCohortSet <- function(cdm,
   return(cdm)
 }
 
+
+#' @rdname generateCohortSet
+#' @export
+generate_cohort_set <- function(cdm,
+                                cohort_set,
+                                name = "cohort",
+                                compute_attrition = FALSE,
+                                overwrite = FALSE) {
+  generateCohortSet(cdm = cdm,
+                    cohortSet = cohort_set,
+                    name = name,
+                    computeAttrition = compute_attrition,
+                    overwrite = overwrite)
+
+}
+
+
 #' Low level constructor for GeneratedCohortSet objects for package developers
 #'
 #' This constructor function is to be used by analytic package developers to
@@ -412,20 +427,20 @@ generateCohortSet <- function(cdm,
 #' and the number of unique persons in each cohort in a `generatedCohortSet`.
 #' It is derived metadata that can be re-derived as long as cohort_set,
 #' the complete list of cohorts in the set, is available. Column names of
-#' cohort_count are: cohort_definition_id, cohort_entries,
-#' cohort_subjects.
+#' cohort_count are: cohort_definition_id, number_records,
+#' number_subjects.
 #'
-#' @param cohort_ref A `tbl_sql` object that points to a remote cohort table
+#' @param cohort_ref,cohortRef A `tbl_sql` object that points to a remote cohort table
 #' with the following first four columns: cohort_definition_id,
 #' subject_id, cohort_start_date, cohort_end_date. Additional columns are
 #' optional.
-#' @param cohort_set_ref A `tbl_sql` object that points to a remote table
+#' @param cohort_set_ref,cohortSetRef A `tbl_sql` object that points to a remote table
 #' with the following first two columns: cohort_definition_id, cohort_name.
 #' Additional columns are optional. cohort_definition_id should be a primary
 #' key on this table and uniquely identify rows.
-#' @param cohort_attrition_ref A `tbl_sql` object that points to an attrition
+#' @param cohort_attrition_ref,cohortAttritionRef A `tbl_sql` object that points to an attrition
 #' table in a remote database with the first column being cohort_definition_id.
-#' @param cohort_count_ref A `tbl_sql` object that points to a cohort_count
+#' @param cohort_count_ref,cohortCountRef A `tbl_sql` object that points to a cohort_count
 #' table in a remote database with columns cohort_definition_id, cohort_entries,
 #' cohort_subjects.
 #'
@@ -457,10 +472,10 @@ generateCohortSet <- function(cdm,
 #'    cohort_ref <- dplyr::tbl(con, name)
 #'    cohort_set <- dplyr::tbl(con, paste0(name, "_set"))
 #'    cohort_attrition_ref <- dplyr::tbl(con, paste0(name, "_attrition"))
-#'    cohort_count_ref <- dplyr::tbl(con, paste0(name, "count"))
+#'    cohort_count_ref <- dplyr::tbl(con, paste0(name, "_count"))
 #'
 #'    # create the generated cohort set object using the constructor
-#'    generatedCohortSet <- newGeneratedCohortSet(
+#'    generatedCohortSet <- new_generated_cohort_set(
 #'       cohort_ref,
 #'       cohort_set_ref = cohort_set_ref,
 #'       cohort_attrition_ref = cohort_attrition_ref,
@@ -471,10 +486,10 @@ generateCohortSet <- function(cdm,
 #'    return(cdm)
 #'  }
 #' }
-newGeneratedCohortSet <- function(cohort_ref,
-                                  cohort_set_ref = NULL,
-                                  cohort_attrition_ref = NULL,
-                                  cohort_count_ref = NULL) {
+new_generated_cohort_set <- function(cohort_ref,
+                                     cohort_set_ref = NULL,
+                                     cohort_attrition_ref = NULL,
+                                     cohort_count_ref = NULL) {
 
   checkmate::assertClass(cohort_ref, classes = c("tbl_sql"), null.ok = FALSE)
   checkmate::assertClass(cohort_set_ref, classes = c("tbl_sql"), null.ok = TRUE)
@@ -507,8 +522,8 @@ newGeneratedCohortSet <- function(cohort_ref,
 
   if (!is.null(cohort_count_ref)) {
     checkmate::assertSubset(c("cohort_definition_id",
-                              "cohort_entries",
-                              "cohort_subjects"),
+                              "number_records",
+                              "number_subjects"),
                             choices = names(cohort_count_ref))
   }
 
@@ -521,6 +536,21 @@ newGeneratedCohortSet <- function(cohort_ref,
   return(cohort_ref)
 }
 
+
+#' @rdname new_generated_cohort_set
+#' @export
+newGeneratedCohortSet <- function(cohortRef,
+                                  cohortSetRef = NULL,
+                                  cohortAttritionRef = NULL,
+                                  cohortCountRef = NULL) {
+  new_generated_cohort_set(cohort_ref = cohortRef,
+                           cohort_set_ref = cohortSetRef,
+                           cohort_attrition_ref = cohortAttritionRef,
+                           cohort_count_ref = cohortCountRef
+                           )
+}
+
+
 #' Get attrition table from a GeneratedCohortSet object
 #'
 #' @param x A generatedCohortSet object
@@ -528,6 +558,12 @@ newGeneratedCohortSet <- function(cohort_ref,
 #' @export
 cohortAttrition <- function(x) { UseMethod("cohortAttrition") }
 
+
+#' @rdname cohortAttrition
+#' @export
+cohort_attrition <- cohortAttrition
+
+
 #' @export
 cohortAttrition.GeneratedCohortSet <- function(x) {
   attr(x, "cohort_attrition")
@@ -540,6 +576,12 @@ cohortAttrition.GeneratedCohortSet <- function(x) {
 #' @export
 cohortSet <- function(x) { UseMethod("cohortSet") }
 
+
+#' @rdname cohortSet
+#' @export
+cohort_set <- cohortSet
+
+
 #' @export
 cohortSet.GeneratedCohortSet <- function(x) {
   attr(x, "cohort_set")
@@ -552,6 +594,12 @@ cohortSet.GeneratedCohortSet <- function(x) {
 #' @export
 cohortCount <- function(x) { UseMethod("cohortCount") }
 
+
+#' @rdname cohortCount
+#' @export
+cohort_count <- cohortCount
+
+
 #' @export
 cohortCount.GeneratedCohortSet <- function(x) {
   attr(x, "cohort_count")
@@ -569,16 +617,19 @@ cohortCount.GeneratedCohortSet <- function(x) {
 # @param cohortSet Cohort set of the generated tables.
 # @param cohortId Cohort definition id of the cohorts that we want to generate
 # the attrition. If NULL all cohorts from cohort set will be used.
+# @param overwrite Should the attrition table be overwritten if it already exists? TRUE or FALSE
 #
 # @importFrom rlang :=
 # @return the attrition as a data.frame
 computeAttritionTable <- function(cdm,
                                   cohortStem,
                                   cohortSet,
-                                  cohortId = NULL) { #browser()
+                                  cohortId = NULL,
+                                  overwrite = FALSE) {
 
   checkmate::assertClass(cdm, "cdm_reference")
   checkmate::assertCharacter(cohortStem, len = 1, min.chars = 1)
+  checkmate::assertLogical(overwrite, len = 1)
   checkmate::assertDataFrame(cohortSet, min.rows = 0, col.names = "named")
   checkmate::assertNames(colnames(cohortSet),
     must.include = c("cohort_definition_id", "cohort")
@@ -596,6 +647,14 @@ computeAttritionTable <- function(cdm,
   schema <- attr(cdm, "write_schema")
   checkmate::assertCharacter(schema, min.len = 1, max.len = 2, min.chars = 1)
 
+  if (paste0(cohortStem, "_attrition") %in% listTables(con, schema = schema)) {
+    if (overwrite) {
+      DBI::dbRemoveTable(con, inSchema(schema, paste0(cohortStem, "_attrition")))
+    } else {
+      rlang::abort(paste0(cohortStem, "_attrition already exists in the database. Set overwrite = TRUE."))
+    }
+  }
+
   # Bring the inclusion result table to R memory
   inclusionResult <- dplyr::tbl(con, inSchema(schema, inclusionResultTableName, dbms(con))) %>%
     dplyr::collect() %>%
